CCL: Globals

CCL

### - _ -

- __CTEST2_INTERNAL : ctest.h
- __CTEST_INTERNAL : ctest.h
- __CTEST_MAGIC : ctest.h
- __CTEST_STRUCT : ctest.h
- __FNAME : ctest.h
- __Test_Section : ctest.h
- __TNAME : ctest.h

### - a -

- A_SPLINE_TYPE : ccl_constants.h
- ASSERT_DATA : ctest.h
- ASSERT_DBL_FAR : ctest.h
- ASSERT_DBL_FAR_TOL : ctest.h
- ASSERT_DBL_NEAR : ctest.h
- ASSERT_DBL_NEAR_TOL : ctest.h
- ASSERT_EQUAL : ctest.h
- ASSERT_EQUAL_U : ctest.h
- ASSERT_FAIL : ctest.h
- ASSERT_FALSE : ctest.h
- ASSERT_INTERVAL : ctest.h
- ASSERT_NOT_EQUAL : ctest.h
- ASSERT_NOT_EQUAL_U : ctest.h
- ASSERT_NOT_NULL : ctest.h
- ASSERT_NULL : ctest.h
- ASSERT_STR : ctest.h
- ASSERT_TRUE : ctest.h

### - b -

- BBKS_TOLERANCE : ccl_test_bbks.c

### - c -

- CCL_ERROR_CLASS : ccl_error.h
- CCL_ERROR_COMPUTECHI : ccl_error.h
- CCL_ERROR_HMF_INTERP : ccl_error.h
- CCL_ERROR_INCONSISTENT : ccl_error.h
- CCL_ERROR_INTEG : ccl_error.h
- CCL_ERROR_LINSPACE : ccl_error.h
- CCL_ERROR_MEMORY : ccl_error.h
- CCL_ERROR_MF : ccl_error.h
- CCL_ERROR_NU_INT : ccl_error.h
- CCL_ERROR_PARAMETERS : ccl_error.h
- CCL_ERROR_ROOT : ccl_error.h
- CCL_ERROR_SPLINE : ccl_error.h
- CCL_ERROR_SPLINE_EV : ccl_error.h
- CCL_MAX_NU_SPECIES : ccl_neutrinos.h
- CCL_NU_MNUT_MAX : ccl_neutrinos.h
- CCL_NU_MNUT_MIN : ccl_neutrinos.h
- CCL_NU_MNUT_N : ccl_neutrinos.h
- CL_TRACER_NC : ccl_cls.h
- CL_TRACER_WL : ccl_cls.h
- CLIGHT : ccl_constants.h
- CLIGHT_HMPC : ccl_constants.h
- CLS_FRACTION : ccl_test_cls.c
- CLS_TOLERANCE : ccl_test_cls.c
- CTEST : ctest.h
- CTEST2 : ctest.h
- CTEST2_SKIP : ctest.h
- CTEST_DATA : ctest.h
- CTEST_MAIN : ccl_test.c
- CTEST_SETUP : ctest.h
- CTEST_SKIP : ctest.h
- CTEST_TEARDOWN : ctest.h

### - d -

- D_SPLINE_TYPE : ccl_constants.h
- DISTANCES_TOLERANCE : ccl_test_distances.c
- DNDZ_NC : ccl_lsst_specs.h
- DNDZ_WL_CONS : ccl_lsst_specs.h
- DNDZ_WL_FID : ccl_lsst_specs.h
- DNDZ_WL_OPT : ccl_lsst_specs.h

### - e -

- EH_TOLERANCE : ccl_test_eh.c
- EPS_SCALEFAC_GROWTH : ccl_constants.h
- EPSREL_DIST : ccl_constants.h
- EPSREL_DNDZ : ccl_constants.h
- EPSREL_GROWTH : ccl_constants.h
- EV_IN_J : ccl_constants.h
- EXPAND_STR : ccl_core.h

### - g -

- GNEWT : ccl_constants.h
- GROWTH_TOLERANCE : ccl_test_growth.c

### - h -

- HH : ccl_sample_run.c
- HPLANCK : ccl_constants.h

### - i -

- INVSIGMA_TOLERANCE : ccl_test_massfunc.c

### - k -

- K_PIVOT : ccl_constants.h
- K_SPLINE_TYPE : ccl_constants.h
- KBOLTZ : ccl_constants.h

### - m -

- M_SPLINE_TYPE : ccl_constants.h
- MASSFUNC_TOLERANCE : ccl_test_massfunc.c
- MNU : ccl_sample_run.c
- MPC_TO_METER : ccl_constants.h

### - n -

- NL : ccl_sample_run.c
- NMAS : ccl_sample_run.c
- NORMPS : ccl_sample_run.c
- NREL : ccl_sample_run.c
- NS : ccl_sample_run.c
- NU_CONST : ccl_neutrinos.h
- NZ : ccl_sample_run.c

### - o -

- OB : ccl_sample_run.c
- OC : ccl_sample_run.c
- OK : ccl_sample_run.c
- ON : ccl_sample_run.c

### - p -

- PC_TO_METER : ccl_constants.h
- PLIN_SPLINE_TYPE : ccl_constants.h
- PNL_SPLINE_TYPE : ccl_constants.h
- PS : ccl_sample_run.c

### - r -

- RHO_CRITICAL : ccl_constants.h

### - s -

- SETUP_FNAME : ctest.h
- SIGMA_TOLERANCE : ccl_test_massfunc.c
- SIGMAM_TOLERANCE : ccl_test_sigmaM.c
- SOLAR_MASS : ccl_constants.h
- STBOLTZ : ccl_constants.h
- STRING : ccl_core.h
- SZ_GC : ccl_sample_run.c
- SZ_SH : ccl_sample_run.c
- SZ_VAL : ccl_test_cls.c

### - t -

- TEARDOWN_FNAME : ctest.h
- TNCDM : ccl_constants.h

### - w -

- W0 : ccl_sample_run.c
- WA : ccl_sample_run.c
- WEAK : ctest.h

### - z -

- Z0_GC : ccl_sample_run.c
- Z0_SH : ccl_sample_run.c
- Z_MAX_SOURCES : ccl_lsst_specs.h
- Z_MIN_SOURCES : ccl_lsst_specs.h
- ZD : ccl_sample_run.c